==> haskell-tasty-checklist-1.0.3.0-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-checklist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-checklist
version:              1.0.3.0
visibility:           public
id:                   tasty-checklist-1.0.3.0-11ff4t6bJoh2k69oPLnAec
key:                  tasty-checklist-1.0.3.0-11ff4t6bJoh2k69oPLnAec
license:              ISC
copyright:            Kevin Quick, 2021
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Check multiple items during a tasty test
description:
    Allows the test to check a number of items during a test and
    only signal pass or fail when the end if the checklist is reached.

    Also provides an easy method to check multiple derived values from
    a single input value.

category:             Testing
abi:                  55fd4e58f42e3337def46e41de92f61e
exposed:              True
exposed-modules:      Test.Tasty.Checklist
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-checklist-1.0.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-checklist-1.0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/tasty-checklist-1.0.3.0
hs-libraries:         HStasty-checklist-1.0.3.0-11ff4t6bJoh2k69oPLnAec
depends:
    base-4.15.1.0 exceptions-0.10.4
    parameterized-utils-2.1.5.0-HYB2TIpLt9v4ukHUT0IpqJ text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-checklist/html/tasty-checklist.haddock

haddock-html:         /usr/share/doc/haskell-tasty-checklist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-checklist-1.0.3.0-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-checklist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-checklist
version:              1.0.3.0
visibility:           public
id:                   tasty-checklist-1.0.3.0-6rhIIGa5cQxEjo7OTPSwkZ
key:                  tasty-checklist-1.0.3.0-6rhIIGa5cQxEjo7OTPSwkZ
license:              ISC
copyright:            Kevin Quick, 2021
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Check multiple items during a tasty test
description:
    Allows the test to check a number of items during a test and
    only signal pass or fail when the end if the checklist is reached.

    Also provides an easy method to check multiple derived values from
    a single input value.

category:             Testing
abi:                  857ab75b931005402b6e276abedc1443
exposed:              True
exposed-modules:      Test.Tasty.Checklist
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-checklist-1.0.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-checklist-1.0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-checklist
hs-libraries:         HStasty-checklist-1.0.3.0-6rhIIGa5cQxEjo7OTPSwkZ
depends:
    base-4.15.1.0 exceptions-0.10.4
    parameterized-utils-2.1.5.0-J1NnfBQy92x5j3wWHini7 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-checklist/html/tasty-checklist.haddock

haddock-html:         /usr/share/doc/haskell-tasty-checklist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
